/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
 *
 * ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 *  Zack Rusin <zack@kde.org>.
 * Portions created by the Initial Developer are Copyright (C) 2004
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Zack Rusin <zack@kde.org>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
#ifndef QECKOGLOBALS_H
#define QECKOGLOBALS_H

#include "prenv.h"

class nsModuleComponentInfo;
class nsIDirectoryServiceProvider;
class nsModuleComponentInfo;
class nsIAppShell;
class nsVoidArray;
class nsProfileDirServiceProvider;
class nsIDirectoryServiceProvider;
class nsIWebBrowserChrome;

class QGeckoGlobals
{
    friend class QGeckoEmbed;
public:
    static void initializeGlobalObjects();
    static void pushStartup();
    static void popStartup();
    static void setCompPath(const char *aPath);
    static void setAppComponents(const nsModuleComponentInfo *aComps,
                                 int aNumComponents);
    static void setProfilePath(const char *aDir, const char *aName);
    static void setDirectoryServiceProvider(nsIDirectoryServiceProvider
                                            *appFileLocProvider);
    static int  startupProfile(void);
    static void shutdownProfile(void);

    static int registerAppComponents();

    static void addEngine(QGeckoEmbed *embed);
    static void removeEngine(QGeckoEmbed *embed);
    static QGeckoEmbed *findPrivateForBrowser(nsIWebBrowserChrome *aBrowser);
private:
    static PRUint32                sWidgetCount;
    // the path to components
    static char                   *sCompPath;
    // the list of application-specific components to register
    static const nsModuleComponentInfo  *sAppComps;
    static int                     sNumAppComps;
    // the appshell we have created
    static nsIAppShell            *sAppShell;
    // what is our profile path?
    static char                   *sProfileDir;
    static char                   *sProfileName;
    // for profiles
    static nsProfileDirServiceProvider *sProfileDirServiceProvider;
    static nsIDirectoryServiceProvider *sAppFileLocProvider;

    // the list of all open windows
    static nsVoidArray            *sWindowList;
};

#endif
